+++
title = "Description meta-data with \"quoted text\""
description = "Some description with \"quoted text\""
date = 2017-07-24
tags = ["front-matter", "description"]
draft = false
+++

Testing a post with double quotes in the description.
